if not DebugLogBackend then return end
local DebugLogBackend = DebugLogBackend

local LibDebugLog = LibStub('LibDebugLog-1.0')

local handler = {}
local options

options = {
	type = 'group',
	handler = handler,
	get = 'GetOption',
	set = 'SetOption',
	disabled = 'IsDisabled',
	args = {
		output = {
			name = 'Output settings',
			type = 'group',
			inline = true,
			order = 100,
			args = {
				enable = {
					name = 'Enable',
					type = 'toggle',
					arg = 'enabled',
					order = 100,
					disabled = false,
				},
				prefix = {
					name = 'Show DEBUG prefix',
					type = 'toggle',
					arg = 'showPrefix',
					order = 110,
				},
				source = {
					name = 'Show source',
					type = 'toggle',
					arg = 'showSource',
					order = 120,
				},
				timestamp = {
					name = 'Show timestamp',
					type = 'toggle',
					arg = 'showTimestamp',
					order = 130,
				},
				chatFrame = {
					name = 'Output chat frame',
					type = 'select',
					arg = 'chatFrame',
					values = 'GetChatFrames',
					order = 140,
				},
			},
		},
		loggers = {
			name = 'Enabled loggers',
			type = 'multiselect',
			values = 'GetLoggerList',
			get = 'GetLoggerStatus',
			set = 'SetLoggerStatus',
			disabled = false,
			order = 110,
		},
	}
}

function handler:GetOption(info)
	local key = info.arg
	return self.db[key]
end

function handler:SetOption(info, value)
	local key = info.arg
	self.db[key] = value
	if key == 'chatFrame' then
		DebugLogBackend:UpdateFrame()
	elseif key == 'enabled' then
		if value then
			DebugLogBackend:Enable()
		else
			DebugLogBackend:Disable()
		end
	end
end

function handler:IsDisabled()
	return not DebugLogBackend:IsEnabled()
end

do
	local list = {}
	function handler:GetChatFrames()
		for k in pairs(list) do list[k] = nil end
		list[0] = 'Default'
		for i = 1,NUM_CHAT_WINDOWS do
			local name, _, _, _, _, _, shown = GetChatWindowInfo(i)
			local frame = _G['ChatFrame'..i]
			if name and frame and (shown or frame.isDocked) then
				list[i] = name
			end
		end
		return list
	end
end

local loggers = {}
do
	local list = {}
	function handler:GetLoggerList()
		for k in pairs(list) do list[k] = nil end
		for k in pairs(loggers) do loggers[k] = nil end
		for logger, name in LibDebugLog:IterateLoggers(true) do
			list[name] = name
			loggers[name] = logger
		end
		return list
	end
end

function handler:GetLoggerStatus(info, name)
	return loggers[name]:IsDebugLogEnabled()
end

function handler:SetLoggerStatus(info, name, value)
	loggers[name]:ToggleDebugLog(value)
end

function DebugLogBackend:BuildOptions(db)
	handler.db = db
	return options
end
